@@ -5,7 +5,8 @@ use utf8;
 use FindBin;
 
 package App::GUI::Harmonograph;
-our $VERSION = '0.4_1'; # TRIAL
+our $NAME = __PACKAGE__;
+our $VERSION = '0.4_2'; # TRIAL
 $VERSION =~ tr/_//d;
 
 use base qw/Wx::App/;
@@ -35,18 +36,34 @@ App::GUI::Harmonograph - sculpting beautiful circular drawings
 
 =head1 SYNOPSIS 
 
+=over 4
 
-    1: start the program (harmonograph.pl )
-    
-    2. push help buttons (down left) to understand GUI and mechanics
-    
-    3. move knobs to interesting configuration
-    
-    4. push "Draw" to produce visible image
+=item 1.
 
-    5. push "Save" to store image in a file
-    
-    6. push "Write" to safe settings into a file for tweaking them later
+start the program (harmonograph)
+
+=item 2.
+
+push help buttons (down left) to understand GUI and mechanics
+
+=item 3.
+
+move knobs to interesting configuration
+
+=item 4.
+
+push "Draw" (below right drawing board) to produce visible / full image
+
+=item 5.
+
+push "Save" (below left) to store image in a PNG / JPEG / SVG file
+
+=item 6.
+
+push "Write" (second row right) to safe settings into a INI file 
+for tweaking them later
+
+=back
 
 =head1 DESCRIPTION
 
@@ -64,6 +81,53 @@ together spiraling pictures :
 
 
 
+
+=head1 Mechanics
+
+This is a cybernetic recreation of an Prof. Blackburns invention with 
+several enhancements:
+
+=over 4
+
+=item *
+
+third pendulum can rotate
+
+=item *
+
+pendula can oscillate at none integer frequncies
+
+=item *
+
+changeable amplitude damping
+
+=item *
+
+changeable dot density and size
+
+=item *
+
+3 types of color changes with changeable speed and polynomial dynamics
+
+=back
+
+
+
+=head1 GUI
+
+=head2 Pendulum
+
+=head2 Line
+
+=head2 Colors
+
+=head1 Workflow
+
+=head2 File Formats
+
+=head2 File Series
+
+
 =head1 AUTHOR
 
 Herbert Breunung (lichtkind@cpan.org)
